@@ -169,6 +169,17 @@ class CDSLShell(BasicShell):
             for active_dict in self.active_dicts:
                 print(active_dict)
 
+    def do_stats(self, text: str = None):
+        """Display statistics about active dictionaries"""
+        if self.active_dicts is None:
+            self.logger.error("Please select a dictionary first.")
+        else:
+            print(f"Total {len(self.active_dicts)} dictionaries are active.")
+            for active_dict in self.active_dicts:
+                print("---")
+                print(active_dict)
+                print(active_dict.stats(output_scheme=self.output_scheme))
+
     # ----------------------------------------------------------------------- #
 
     def do_dicts(self, text: str = None):
@@ -291,7 +302,17 @@ class CDSLShell(BasicShell):
 
     # ----------------------------------------------------------------------- #
 
-    def default(self, line: str):
+    def do_search(self, line: str):
+        """
+        Search in the active dictionaries
+
+        Note
+        ----
+        * Searching in the active dictionaries is also the default action.
+        * In general, we do not need to use this command explicitly unless we
+          want to search the command keywords, such as, `available` `search`,
+          `version`, `help` etc. in the active dictionaries.
+        """
         if self.active_dicts is None:
             self.logger.error("Please select a dictionary first.")
         else:
@@ -313,6 +334,13 @@ class CDSLShell(BasicShell):
                         )
                     )
 
+    # ----------------------------------------------------------------------- #
+
+    def default(self, line: str):
+        self.do_search(line)
+
+    # ----------------------------------------------------------------------- #
+
     def cmdloop(self, intro: str = None):
         print(self.intro)
         print(self.desc)
