@@ -16,7 +16,7 @@ LOGGER = logging.getLogger(__name__)
 ###############################################################################
 
 
-def validate_scheme(scheme):
+def validate_scheme(scheme: str) -> str or None:
     """Validate the name of transliteration scheme
 
     Parameters
@@ -31,16 +31,22 @@ def validate_scheme(scheme):
         otherwise, None.
     """
     if scheme is not None:
-        scheme = scheme.lower() if scheme.lower() in SCHEMES else None
-        if scheme is None:
+        _scheme = scheme.lower() if scheme.lower() in SCHEMES else None
+        if _scheme is None:
             LOGGER.warning(f"Invalid transliteration scheme '{scheme}'.")
+    else:
+        _scheme = None
 
-    return scheme
+    return _scheme
 
 
 def transliterate_between(
-    text, from_scheme, to_scheme, start_pattern, end_pattern
-):
+    text: str,
+    from_scheme: str,
+    to_scheme: str,
+    start_pattern: str,
+    end_pattern: str
+) -> str:
     """Transliterate the text appearing between two patterns
 
     Only the text appearing between patterns `start_pattern` and `end_pattern`
